==> corepaint-4.1.0.tar.gz: corepaint-v4.1.0/main.cpp <==
/*
    *
    * This file is a part of CorePaint.
    * A paint app for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/


#include <QApplication>
#include <QCommandLineParser>
#include <QFileInfo>

#include "corepaint.h"


int main(int argc, char *argv[])
{
#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
#endif

    QApplication app(argc, argv);
    app.setQuitOnLastWindowClosed(true);

    // Set application info
    app.setOrganizationName("CuboCore");
    app.setApplicationName("CorePaint");

    QCommandLineParser parser;
    parser.addHelpOption();
    parser.addVersionOption();

    const QString files = "[FILE1, FILE2,...]";
    parser.addPositionalArgument("files", files, files);
    parser.process(app);

    QStringList args = parser.positionalArguments();
    QStringList paths;

    foreach (QString arg, args) {
        QFileInfo info(arg);
        paths.push_back(info.absoluteFilePath());
    }

    corepaint e;

    if (paths.count()) {
        e.sendFiles(paths);
    }

    e.show();

    return app.exec();
}

==> corepaint-4.5.0.tar.gz: corepaint-v4.5.0/main.cpp <==
/*
    *
    * This file is a part of CorePaint.
    * A paint app for C Suite.
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/


#include <QApplication>
#include <QCommandLineParser>
#include <QFileInfo>

#include "corepaint.h"


int main(int argc, char *argv[])
{
    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
    QApplication app(argc, argv);

    // Set application info
    app.setOrganizationName("CuboCore");
    app.setApplicationName("CorePaint");
    app.setApplicationVersion(QStringLiteral(VERSION_TEXT));
    app.setDesktopFileName("org.cubocore.CorePaint.desktop");
    app.setQuitOnLastWindowClosed(true);

    QCommandLineParser parser;
    parser.addHelpOption();
    parser.addVersionOption();
	parser.addPositionalArgument("files", "Image files you want to edit or draw");
    parser.process(app);

    QStringList args = parser.positionalArguments();
    QStringList paths;

	Q_FOREACH (QString arg, args) {
        QFileInfo info(arg);
        paths.push_back(info.absoluteFilePath());
    }

    corepaint e;

    if (paths.count()) {
        e.sendFiles(paths);
    }

    e.show();

    return app.exec();
}
